from pydantic import BaseModel

# pypi-AgEIcHlwaS5vcmcCJDllZjhkN2I0LTgzNzctNGJkZS1hNzk3LWRhYmFjN2Q3YTE4OAACKlszLCIzNzNiNGI0Yy01NzE0LTRkODQtYTk2OC1kMzdlYjI5MmYxYjIiXQAABiCe6rs_EYAilA8jd5vBIsoBggA3Qe2ILmIQGZCawXfiBA


class Item(BaseModel):
    """
    Вещи

    :param name: название
    :type name: obj:`str`

    :param description: описание
    :type description: obj:`str`

    :param price: цена
    :type price: obj:`float`

    :param tax: налог
    :type tax: obj:`float`
    """
    name: str
    """Имя"""
    description: str | None = None
    """Описание"""
    price: float
    """Цена"""
    tax: float | None = None
    """Налог"""

class User:
    def __init__(self, name: str, age: int):
        self.name = name
        self.age = age
        self.balance = 100

    def get_price(self):
        return Item.price


from setuptools import setup, find_packages


with open('README.md', encoding="utf-8") as f:
  long_description = f.read()


setup(
  name='qwertyuiopl',
  version='1.1',
  author='tosterLIKE',
  author_email='090504opo@gmail.com',
  description='Тест',
  long_description=long_description,
  long_description_content_type='text/markdown',
  url='https://github.com/xllebbSQ/aiopayAPI',
  packages=find_packages(),
  install_requires=['aiohttp>=3.8.5',
                    "asyncio>=3.4.3",
                    "typing>=3.7.4",
                    "pydantic>=1.8.2"],
  classifiers=[
    'Programming Language :: Python :: 3.8',
    'Programming Language :: Python :: 3.9',
    'Programming Language :: Python :: 3.10',
    'Programming Language :: Python :: 3.11',
    'License :: OSI Approved :: MIT License',
    'Operating System :: OS Independent'
  ],
  python_requires='>=3.8'
)